@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Node base classes.
@@ -185,6 +185,19 @@ class NodeBase(NodeMetaClassBase):
 
         return parent
 
+    def getContainingLoopNode(self):
+        """Return the parent that is module."""
+        parent = self.parent
+
+        while parent is not None and not parent.isExpressionFunctionBodyBase():
+
+            if parent.isStatementLoop():
+                return parent
+
+            parent = parent.getParent()
+
+        return parent
+
     def isParentVariableProvider(self):
         # Check if it's a closure giver, in which cases it can provide variables,
         return isinstance(self, ClosureGiverNodeMixin)
@@ -314,6 +327,10 @@ class NodeBase(NodeMetaClassBase):
     def isStatementsFrame():
         return False
 
+    @staticmethod
+    def isStatementsSequenceButNotFrame():
+        return False
+
     @staticmethod
     def isCompiledPythonModule():
         # For overload by module nodes
@@ -405,6 +422,11 @@ class NodeBase(NodeMetaClassBase):
     def getVisitableNodes():
         return ()
 
+    def checkChildren(self):
+        for c in self.getVisitableNodes():
+            assert c.parent is self, (c, "parent", self, "!=", c.parent)
+            c.checkChildren()
+
     @staticmethod
     def getVisitableNodesNamed():
         """Named children dictionary.
@@ -707,6 +729,11 @@ class StatementBase(NodeBase):
             expression = trace_collection.onExpression(expression)
 
             if expression.willRaiseAnyException():
+                # They probably have changed.
+                expressions = self.getVisitableNodes()
+
+                child_name = expression.getChildNameNice()
+
                 wrapped_expression = makeStatementOnlyNodesFromExpressions(
                     expressions[: count + 1]
                 )
@@ -717,7 +744,7 @@ class StatementBase(NodeBase):
                     wrapped_expression,
                     "new_raise",
                     lambda: "For %s the child expression '%s' will raise."
-                    % (self.getStatementNiceName(), expression.getChildNameNice()),
+                    % (self.getStatementNiceName(), child_name),
                 )
 
         return self, None, None
